# Common Instalation Issues

## `ImportError: No module named _markerlib`

Run `easy_install Distribute`

## Exception installing pycrypto

    env "CFLAGS=-I/usr/local/include -L/usr/local/lib" pip install pycrypto

